/*
 *  isp.h ..... 'C' header for the ISP module, which demonstrates
 *  SLDC In System Programming.
 */

/* prevent multiple inclusion of this file: */
#ifndef _ISP_H
#define _ISP_H


/* -------------------------------------------------------------------------- */
/* HEADER FILES                                                               */
/* -------------------------------------------------------------------------- */

/* System headers required by this file: */
#include <stdio.h>

/* Additional headers required by this file: */
#include "slcd.h"
#include "commonDefs.h"


/* -------------------------------------------------------------------------- */
/* PUBLIC TYPES                                                               */
/* -------------------------------------------------------------------------- */

// map of the trailer data SLCDM BMPLoad puts at the end of a .BIN file:
// -- see "m_strctStatus" definition in SLCDM's BMPloadDlg.h
typedef struct
{
	unsigned int nSignature;
	unsigned char chCRC_VALID;
	char szCRCVal[7];
	unsigned int nIspowerOnMacroActive;
	unsigned int nIsSplashScreenActive;
	unsigned int nIsTypematicParametersActive;
	unsigned int nIsTouchDebounceActive;
	unsigned int nIsCustomPaletteActive;
	unsigned int nIsHiColorActive;
	unsigned int nIsUpgradable;
	unsigned int nIsCompressActive;
	unsigned int nIsAuxEscapeActive;
	unsigned int nIsControlPortActive;
	unsigned char chPowerOnmacroActive;
	unsigned char chSplashScreenActive;
	unsigned char chTypematicParametersDelayActive;
	unsigned char chTypematicParametersRepeatActive;
	unsigned char chTouchDebounceActive;
	char chAuxEscapeActive[3];
	unsigned char chControlPortActive;
	unsigned char update;	// f/w update included
	unsigned int nIsOrientation;
} ISP_SLCDx_TrailerData_t;


/* -------------------------------------------------------------------------- */
/* PROTOTYPES FOR PUBLIC CODE                                                 */
/* -------------------------------------------------------------------------- */

// Validate .BIN file data has correct validation code:
// -- ASSUMES file is already opened for binary read
// -- returns TRUE if successful, else FALSE.
BOOL ISP_ValidateBinFile( SLCD_Model_t model, FILE *fp, long imageFileSize );

// Get SLCDx BMPLoad's trailer data from the end of the file:
// -- only used for SLCDx; SLCD5/SLCD5+ BMPLoad does not append trailer data
// -- ASSUMES file is already opened for binary read
// -- returns TRUE if successful, else FALSE.
BOOL ISP_GetFileTrailerData( FILE *fp, ISP_SLCDx_TrailerData_t *pTrailer );

// Get size of External Flash:
// -- returns TRUE if successful, else FALSE.
BOOL ISP_GetExtFlashSize( SLCD_Model_t model, long *flashSize, long *sectorSize );

// Erase enough External Flash to hold the image:
// -- returns TRUE if successful, else FALSE.
BOOL ISP_EraseExtFlash( SLCD_Model_t model, long imageSize, long sectorSize );

// Write the image from the file into External Flash:
// -- ASSUMES file is already opened for binary read
// -- returns TRUE if successful, else FALSE.
BOOL ISP_WriteFileToExtFlash( SLCD_Model_t model, FILE *fp, long imageSize );

// Validate the External Flash:
// -- ASSUMES file is already opened for binary read
// -- returns TRUE if successful, else FALSE.
BOOL ISP_ValidateExtFlash( SLCD_Model_t model, FILE *fp, long imageSize );

// Upgrade Program Flash from the image in External Flash:
// -- used by SLCDx only, which supports f/w upgrade in .BIN file
// -- returns TRUE if successful, else FALSE.
BOOL ISP_UpgradeProgFlash( void );


/* end of multiple inclusion protection: */
#endif  /* not _ISP_H */

/* ----- END OF FILE ----- */
