/*
 *  serIO.h ..... 'C' header for the SERIAL I/O module.
 */

/* prevent multiple inclusion of this file: */
#ifndef _SERIO_H
#define _SERIO_H


/* -------------------------------------------------------------------------- */
/* HEADER FILES                                                               */
/* -------------------------------------------------------------------------- */

/* Additional headers required by this file: */
#include "commonDefs.h"


/* -------------------------------------------------------------------------- */
/* PUBLIC CONSTANTS                                                           */
/* -------------------------------------------------------------------------- */

// Read timeout, in mSec:
#define SERIO_READ_TIMEOUT_MSEC     (10)


/* -------------------------------------------------------------------------- */
/* PROTOTYPES FOR PUBLIC CODE                                                 */
/* -------------------------------------------------------------------------- */

// open the comm port:
// -- read timeout is set for 10 milliseconds
// -- write timeout is disabled
// -- port is set for specified baudrate, 8N1, Xon/Xoff TX flow ctl, binary xfer mode
// -- returns TRUE if successful
BOOL SERIO_Open( char *comPortName, int baud );

// close the comm port:
void SERIO_Close( void );

// get a char from the serial port (or timeout):
// -- returns -1 if no char received
int SERIO_GetChar( void );

// send a char to the serial port:
void SERIO_PutChar( char ch );

// send a string to the serial port:
void SERIO_PutString( char *str );

// send the contents of a binary buffer to the serial port:
void SERIO_SendBytes( char *buf, int len );

// flush the input buffer for the requested amount of time:
void SERIO_FlushInput( int mSec );


/* end of multiple inclusion protection: */
#endif  /* not _SERIO_H */

/* ----- END OF FILE ----- */
